API Reference
=============

This page presents the complete API documentation.

.. autosummary::
    :toctree: generated

    data_validation_framework
    data_validation_framework.task
    data_validation_framework.report
    data_validation_framework.result
    data_validation_framework.target
    data_validation_framework.util
    data_validation_framework.rst_tools
